@@ -112,8 +112,8 @@ public:
 			   Request::State state) = 0;
 
   virtual void consumeWebSocketMessage(ws_opcode opcode,
-				       Buffer::const_iterator begin,
-				       Buffer::const_iterator end,
+				       const char* begin,
+				       const char* end,
 				       Request::State state);
 
   void setConnection(ConnectionPtr connection);
@@ -121,6 +121,8 @@ public:
   bool nextBuffers(std::vector<asio::const_buffer>& result);
   bool closeConnection() const;
   void setCloseConnection() { closeConnection_ = true; }
+  void detectDisconnect(const boost::function<void()>& callback);
+
 
   void addHeader(const std::string name, const std::string value);
 
@@ -155,6 +157,7 @@ protected:
 
   ConnectionPtr connection() const { return connection_; }
   bool transmitting() const { return transmitting_; }
+  asio::const_buffer buf(const std::string &s);
 
 private:
 
@@ -179,7 +182,6 @@ private:
   // pointers in the asio buffer lists to become invalid
   std::list<std::string> bufs_;
 
-  asio::const_buffer buf(const std::string &s);
 
   bool encodeNextContentBuffer(std::vector<asio::const_buffer>& result,
 			       int& originalSize, int& encodedSize);
