@@ -23,6 +23,10 @@
 #include "Buffer.h"
 #include "Reply.h"
 
+#ifdef WTHTTP_WITH_ZLIB
+#include <zlib.h>
+#endif
+
 namespace http {
 namespace server {
 
@@ -41,6 +45,7 @@ public:
 
   /// Construct ready to parse the request method.
   RequestParser(Server *server);
+  ~RequestParser();
 
   /// Reset to initial parser state.
   void reset();
@@ -59,6 +64,11 @@ public:
 		 Buffer::iterator& begin, Buffer::iterator end);
 
   bool initialState() const;
+  
+
+#ifdef WTHTTP_WITH_ZLIB
+  bool frameCompressed_;
+#endif
 
 
 private:
@@ -89,6 +99,12 @@ private:
   std::string doWebSocketHandshake13(const Request& req);
   bool parseCrazyWebSocketKey(const buffer_string& key, ::uint32_t& number);
 
+#ifdef WTHTTP_WITH_ZLIB
+  bool doWebSocketPerMessageDeflateNegotiation(const Request& req, std::string& compressHeader);
+  bool inflate(unsigned char* in, size_t size, unsigned char out[], bool& hasMore);
+  bool initInflate();
+#endif
+
   /// The current state of the request parser.
   enum http_state
   {
@@ -130,6 +146,13 @@ private:
     ws13_payload
   } wsState_;
 
+
+#ifdef WTHTTP_WITH_ZLIB
+  z_stream zInState_;
+  bool inflateInitialized_;
+#endif
+  uint64_t read_;
+
   // used for ws00 frameType or ws13 opcode byte
   unsigned char wsFrameType_;
   unsigned char wsCount_;
@@ -147,6 +170,8 @@ private:
   buffer_string *currentString_;
   unsigned maxSize_;
   bool haveHeader_;
+
+  Server *server_;
 };
 
 } // namespace server
