@@ -157,7 +157,7 @@ WT_DECLARE_WT_MEMBER
        return overflow == 'visible' || overflow == 'none';
      }
 
-    if (WT.isGecko &&
+     if (WT.isGecko &&
 	 !element.style[DC.size] &&
 	 dir == HORIZONTAL &&
 	 isNone(WT.css(element, 'overflow'))) {
@@ -233,7 +233,7 @@ WT_DECLARE_WT_MEMBER
      if (asSet)
        return [scrollSize, scrollBar];
 
-     if (WT.isGecko && 
+     if ((WT.isGecko || WT.isWebKit) &&
 	 dir == HORIZONTAL && 
 	 element.getBoundingClientRect().width != 
 	 Math.ceil(element.getBoundingClientRect().width))
@@ -374,8 +374,7 @@ WT_DECLARE_WT_MEMBER
          OC = DirConfig[dir ^ 1],
          measures = DC.measures,
          dirCount = DC.config.length,
-         otherCount = OC.config.length,
-         maxSize = DC.maxSize;
+         otherCount = OC.config.length;
 
      var prevMeasures = measures.slice();
      if (prevMeasures.length == 5) {
@@ -396,8 +395,7 @@ WT_DECLARE_WT_MEMBER
 	 DC.minSize -= sizePadding(container, dir);
      }
 
-     var preferredSize = [], minimumSize = [],
-       totalPreferredSize = 0, totalMinSize = 0, di, oi;
+     var preferredSize = [], minimumSize = [], di, oi;
 
      var measurePreferredForStretching = true, spanned = false;
 
@@ -488,8 +486,6 @@ WT_DECLARE_WT_MEMBER
 		 item.ms[dir] = wMinimum;
 	       } else
 		 wMinimum = item.ms[dir];
-	       if (wMinimum > dMinimum)
-		 dMinimum = wMinimum;
 
 	       /*
 		* if we do not have an size set, we can and should take into
@@ -572,6 +568,7 @@ WT_DECLARE_WT_MEMBER
 		     && (DC.config[di][STRETCH] > 0)
 		     && item.set[dir];
 
+
 		   if (sizeSet || stretching) 
 		     wPreferred = Math.max(wPreferred, item.ps[dir]);
 		   else 
@@ -593,6 +590,8 @@ WT_DECLARE_WT_MEMBER
 	       if (!item.span || item.span[dir] == 1) {
 		 if (wPreferred > dPreferred)
 		   dPreferred = wPreferred;
+		 if (wMinimum > dMinimum)
+		   dMinimum = wMinimum;
 	       } else
 		 spanned = true;
 	     } else {
@@ -638,10 +637,10 @@ WT_DECLARE_WT_MEMBER
      if (spanned) {
        if (debug)
 	 console.log("(before spanned) "
-		     + id + ': ' + dir + " ps " + preferredSize);
+		     + id + ': ' + dir + " ps " + preferredSize + " ms " + minimumSize);
 
        function handleOverspanned(getItemSize, sizes) {
-	 for (di = 0; di < dirCount; ++di) {
+	 for (di = dirCount - 1; di >= 0; --di) {
 	   for (oi = 0; oi < otherCount; ++oi) {
 	     var item = DC.getItem(di, oi);
 
@@ -656,6 +655,9 @@ WT_DECLARE_WT_MEMBER
 		   ++count;
 		   if (DC.config[di + si][STRETCH] > 0)
 		     stretch += DC.config[di + si][STRETCH];
+
+		   if (si != 0)
+		     ps -= DC.margins[SPACING];
 		 }
 	       }
 
@@ -674,7 +676,7 @@ WT_DECLARE_WT_MEMBER
 			 portion = 1;
 
 		       if (portion > 0) {
-			 var fract = Math.round(ps / portion);
+			 var fract = Math.round(ps * (portion / count));
 			 ps -= fract; count -= portion;
 			 sizes[di + si] += fract;
 		       }
@@ -687,7 +689,7 @@ WT_DECLARE_WT_MEMBER
 	   }
 	 }
        }
-	 
+	
        handleOverspanned(function(item) { return item.ps[dir]; },
 			 preferredSize);
 
@@ -695,6 +697,19 @@ WT_DECLARE_WT_MEMBER
 			 minimumSize);
      }
 
+
+     var totalPreferredSize = 0, totalMinSize = 0;
+
+     for (di = 0; di < dirCount; ++di) {
+       if (minimumSize[di] > preferredSize[di])
+	 preferredSize[di] = minimumSize[di];
+
+       if (minimumSize[di] > -1) {
+	 totalPreferredSize += preferredSize[di];
+	 totalMinSize += minimumSize[di];
+       }
+     }
+
      var totalMargin = 0, first = true, rh = false;
      for (di = 0; di < dirCount; ++di) {
        if (minimumSize[di] > -1) {
@@ -718,7 +733,7 @@ WT_DECLARE_WT_MEMBER
      totalMinSize += totalMargin;
 
      if (debug)
-       console.log("measured " + id + ': ' + dir + " ps " + preferredSize);
+       console.log("measured " + id + ': ' + dir + " ps " + preferredSize + " ms " + minimumSize);
 
      DC.measures = [
 	     preferredSize,
@@ -762,7 +777,6 @@ WT_DECLARE_WT_MEMBER
       * mark the corresponding cell as dirty if the TOTAL_PREFERRED_SIZE
       * has changed (or force).
       */
-
      if (parent && parentItemWidget.id) {
        var piw = WT.$(parentItemWidget.id);
        if (piw) {
@@ -876,13 +890,28 @@ WT_DECLARE_WT_MEMBER
    }
 
    // does this column/row have an adjacent handle?
-   function hasResizeHandle(config, di) {
-     if (di == 0) {
-       return (config[di][RESIZABLE] !== 0);
-     } else {
-       return (config[di-1][RESIZABLE] !== 0 ||
-	       config[di][RESIZABLE] !== 0);
+   function hasResizeHandle(DC, di) {
+     var dirCount = DC.config.length;
+
+     var isResizable = DC.config[di][RESIZABLE] !== 0;
+     var i;
+
+     if (isResizable) {
+       /* Check that we are not the last column/row */
+       for (i = di + 1; i < dirCount; ++i) {
+	 if (DC.measures[MINIMUM_SIZE][i] > -1)
+	   return true;
+       }
      }
+
+     /* See if preceding column/row has a resize handle */
+     for (i = di - 1; i >= 0; --i) {
+       if (DC.measures[MINIMUM_SIZE][i] > -1) {
+	 return DC.config[i][RESIZABLE] !== 0;
+       }
+     }
+
+     return false;
    }
 
    function apply(dir, widget) {
@@ -898,12 +927,18 @@ WT_DECLARE_WT_MEMBER
        if (container) {
 	 var pc = WT.css(container, 'position');
 
-	 if (pc === 'absolute')
-	   cSize = WT.pxself(container, DC.size);
+	 var sizedByAnimation = dir == 1 &&
+	       typeof container.nativeHeight !== 'undefined';
+
+	 if (pc === 'absolute') {
+	   if (sizedByAnimation) {
+	     cSize = WT.parsePx(container.nativeHeight);
+	   } else
+	     cSize = WT.pxself(container, DC.size);
+         }
 
 	 if (cSize === 0) {
 	   if (!DC.initialized) {
-
 	     if (dir === HORIZONTAL && (pc === 'absolute' || pc === 'fixed')) {
 	       /*
 		* On Chrome, somehow clientWidth is not reliable until
@@ -914,7 +949,8 @@ WT_DECLARE_WT_MEMBER
 	       container.style.display = '';
 	     }
 
-	     cSize = dir ? container.clientHeight : container.clientWidth;
+	     if (!sizedByAnimation)
+	       cSize = dir ? container.clientHeight : container.clientWidth;
 
 	     cClientSize = true;
 
@@ -1080,25 +1116,23 @@ WT_DECLARE_WT_MEMBER
 
 	   var fs = -1;
 
-	   /* if resizable was disabled, remove fixedSize and go back to 
+	   /*
+	    * if resizable was disabled, remove fixedSize and go back to 
 	    * using the preferred size
 	    */
-	   if (typeof DC.fixedSize[di] !== "undefined"
-	       && ! hasResizeHandle(DC.config, di) ) {
+	   if (!hasResizeHandle(DC, di))
 	     DC.fixedSize[di] = undefined;
-	   }
+
 	   /*
 	    * If we have a fixedSize (set by resizing) then we should
 	    * take it into account only if the resizer is still visible.
-	    *
-	    * This probably isn't entirely accurate, but neither is resizers
-	    * when hiding/showing widgets ?
 	    */
 	   if (typeof DC.fixedSize[di] !== "undefined"
 	       && (di + 1 == dirCount || measures[MINIMUM_SIZE][di + 1] > -1))
 	     fs = DC.fixedSize[di];
-	   else if ((DC.config[di][RESIZABLE] !== 0)
-		    && (DC.config[di][RESIZABLE][RS_INITIAL_SIZE] >= 0)) {
+	   else if (hasResizeHandle(DC, di) &&
+		    DC.config[di][RESIZABLE] !== 0 &&
+		    (DC.config[di][RESIZABLE][RS_INITIAL_SIZE] >= 0)) {
 	     fs = DC.config[di][RESIZABLE][RS_INITIAL_SIZE];
 	     if (DC.config[di][RESIZABLE][RS_PCT])
 	       fs = (cSize - measures[TOTAL_MARGIN]) * fs / 100;
@@ -1158,9 +1192,12 @@ WT_DECLARE_WT_MEMBER
 
 	     var factor = toDistribute / totalStretch;
 
+	     var r = 0;
 	     for (di = 0; di < dirCount; ++di) {
 	       if (stretch[di] > 0) {
-		 targetSize[di] += Math.round(stretch[di] * factor);
+		 var oldr = r;
+		 r += stretch[di] * factor;
+		 targetSize[di] += Math.round(r) - Math.round(oldr);
 		 DC.stretched[di] = true;
 	       }
 	     }
@@ -1175,18 +1212,21 @@ WT_DECLARE_WT_MEMBER
 
 	   var factor;
 
-	   if (totalPreferred[category] - totalMinimum[category] > 0)
+	   if (totalPreferred[category] - totalMinimum[category] > 0) {
 	     factor = (toDistribute - totalMinimum[category])
 	       / (totalPreferred[category] - totalMinimum[category]);
-	   else
+	   } else
 	     factor = 0;
 
+	   var r = 0;
 	   for (di = 0; di < dirCount; ++di) {
 	     if (stretch[di] > 0) {
-	       var s = measures[PREFERRED_SIZE][di]
+	       var s = measures[PREFERRED_SIZE][di] 
 		 - measures[MINIMUM_SIZE][di];
-	       targetSize[di] = measures[MINIMUM_SIZE][di]
-		 + Math.round(s * factor);
+	       var oldr = r;
+	       r += s * factor;
+	       targetSize[di] = measures[MINIMUM_SIZE][di] 
+		 + Math.round(r) - Math.round(oldr);
 	     }
 	   }
 	 }
@@ -1204,18 +1244,21 @@ WT_DECLARE_WT_MEMBER
 
 	 var factor;
 
-	 if (totalPreferred[category] - totalMinimum[category] > 0)
+	 if (totalPreferred[category] - totalMinimum[category] > 0) {
 	   factor = (toDistribute - totalMinimum[category])
 	     / (totalPreferred[category] - totalMinimum[category]);
-	 else
+	 } else
 	   factor = 0;
 
+	 var r = 0;
 	 for (di = 0; di < dirCount; ++di) {
 	   if (stretch[di] == 0) {
 	     var s = measures[PREFERRED_SIZE][di]
 	       - measures[MINIMUM_SIZE][di];
+	     var oldr = r;
+	     r += s * factor;
 	     targetSize[di] = measures[MINIMUM_SIZE][di]
-	       + Math.round(s * factor);
+	       + Math.round(r) - Math.round(oldr);
 	   }
 	 }
        }
@@ -1274,6 +1317,12 @@ WT_DECLARE_WT_MEMBER
 	   first = false;
 	 else
 	   left += DC.margins[SPACING];
+       } else {
+	 if (DC.resizeHandles[di]) {
+	   var handle = WT.getElement(DC.resizeHandles[di]);
+	   handle.parentNode.removeChild(handle);
+	   DC.resizeHandles[di] = undefined;
+	 }
        }
 
        for (oi = 0; oi < otherCount; ++oi) {
@@ -1327,14 +1376,8 @@ WT_DECLARE_WT_MEMBER
 	     if (!hidden && (setSize || ts != ps || item.layout)) {
 	       if (setCss(w, DC.size, tsm + 'px')) {
 		 /*
-		  * Setting a size cancels the built-in margin!
+		  * Setting a size no longer cancels the built-in margin!
 		  */
-		 if (!WT.isIE && (WT.hasTag(w, 'TEXTAREA') ||
-				  WT.hasTag(w, 'INPUT'))) {
-		   setCss(w, 'margin-' + DC.left, item.margin[dir]/2 + 'px');
-		   setCss(w, 'margin-' + OC.left, item.margin[!dir]/2 + 'px');
-		 }
-
 		 setItemDirty(item, 1);
 		 item.set[dir] = true;
 	       }
@@ -1591,8 +1634,15 @@ WT_DECLARE_WT_MEMBER
 	 }
 
 	 var container = widget.parentNode;
-	 for (var i = 0; i < 2; ++i)
-	   DirConfig[i].sizeSet = WT.pxself(container, DirConfig[i].size) != 0;
+	 for (var i = 0; i < 2; ++i) {
+	    var sizedByAnimation = i == 1 &&
+	       typeof container.nativeHeight !== 'undefined';
+	   if (sizedByAnimation)
+	     DirConfig[i].sizeSet = WT.parsePx(container.nativeHeight) != 0;
+	   else
+	     DirConfig[i].sizeSet = WT.pxself(container, DirConfig[i].size)
+	       != 0;
+	 }
        }
    }
 
