@@ -12,10 +12,13 @@
 
 WT_DECLARE_WT_MEMBER
 (1, JavaScriptConstructor, "WDoubleValidator",
-   function(mandatory, bottom, top, decimalPoint, groupSeparator, blankError,
+   function(mandatory, ignoreTrailingSpaces, bottom, top, decimalPoint, groupSeparator, blankError,
 	    NaNError, tooSmallError, tooLargeError) {
      this.validate = function(text) {
        text = String(text);
+	   
+	   if (ignoreTrailingSpaces) 
+		 text = text.trim();
 
        function toRegexp(value) {
 	  return value.replace(new RegExp("([\\^\\\\\\][\\-.$*+?()|{}])","g"), "\\$1");
@@ -32,6 +35,9 @@ WT_DECLARE_WT_MEMBER
        if (decimalPoint != '.')
 	 text = text.replace(decimalPoint, '.');
 
+	   if(text.indexOf(' ') >= 0 && !ignoreTrailingSpaces)
+		 return { valid: false, message: NaNError };
+
        var n = Number(text);
 
        if (isNaN(n))
