@@ -29,7 +29,7 @@ WT_DECLARE_WT_MEMBER
    this.initialized = false;
    this.preloadingTextures = 0;
    this.preloadingBuffers = 0;
-   this.jsValues = [];
+   this.jsValues = {};
 
    this.discoverContext = function(noGLHandler, antialiasingEnabled) {
      if (canvas.getContext) {
@@ -84,6 +84,8 @@ WT_DECLARE_WT_MEMBER
      var doubleTouch = null;
      var dragPreviousXY = null;
 
+     var thisHandler = this;
+
      this.mouseDown = function(o, event) {
        WT.capture(null);
        WT.capture(canvas);
@@ -177,9 +179,9 @@ WT_DECLARE_WT_MEMBER
        doubleTouch = event.touches.length === 2 ? true : false;
 
        if (noTouch)
-	 this.mouseUp(null, null);
+	 thisHandler.mouseUp(null, null);
        if (singleTouch || doubleTouch)
-	 this.touchStart(o, event);
+	 thisHandler.touchStart(o, event);
      };
 
      this.touchMoved = function(o, event) {
@@ -187,8 +189,12 @@ WT_DECLARE_WT_MEMBER
 	 return;
 
        event.preventDefault();
-       if (singleTouch)
-	 this.mouseDrag(o, event.touches[0]);
+       if (singleTouch) {
+	 if (dragPreviousXY === null)
+	    return;
+	 var c = WT.pageCoordinates(event);
+	 rotate(c);
+       }
        if (doubleTouch) {
 	 var c0 = WT.pageCoordinates(event.touches[0]);
 	 var c1 = WT.pageCoordinates(event.touches[1]);
@@ -213,6 +219,8 @@ WT_DECLARE_WT_MEMBER
      var walkYawRate = yawRate;
      var dragPreviousXY = null;
 
+     var thisHandler = this;
+
      this.mouseDown = function(o, event) {
        WT.capture(null);
        WT.capture(canvas);
@@ -275,12 +283,12 @@ WT_DECLARE_WT_MEMBER
        mouseHandler.touchStart(o, event);
    };
    this.touchEnd = function(o, event) {
-     if ((this.initialized || !this.ctx) && mouseHandler && mouseWheel.touchEnd)
-       mouseWheel.touchEnd(o, event);
+     if ((this.initialized || !this.ctx) && mouseHandler && mouseHandler.touchEnd)
+       mouseHandler.touchEnd(o, event);
    };
    this.touchMoved = function(o, event) {
-     if ((this.initialized || !this.ctx) && mouseHandler && mouseWheel.touchMoved)
-       mouseWheel.touchMoved(o, event);
+     if ((this.initialized || !this.ctx) && mouseHandler && mouseHandler.touchMoved)
+       mouseHandler.touchMoved(o, event);
    };
 
    // To be called after a load of buffer/texture completes; will
@@ -309,16 +317,18 @@ WT_DECLARE_WT_MEMBER
    function encodeJSValues() {
      var obj = jQuery.data(canvas, 'obj');
      var str = '';
-     for (var index=0; index < obj.jsValues.length; index++) {
-       str += index + ':';
-       for (var i=0; i < obj.jsValues[index].length; i++) {
-	 str += obj.jsValues[index][i];
-	 if (i !== obj.jsValues[index].length - 1) {
-	   str += ',';
-	 } else {
-	   str += ';';
-	 }
-       }
+     for (var index in obj.jsValues) {
+	if (obj.jsValues.hasOwnProperty(index)) {
+	  str += index + ':';
+	  for (var i=0; i < obj.jsValues[index].length; i++) {
+	    str += obj.jsValues[index][i];
+	    if (i !== obj.jsValues[index].length - 1) {
+	      str += ',';
+	    } else {
+	      str += ';';
+	    }
+	  }
+        }
      }
      return str;
    }
