@@ -151,6 +151,7 @@ public:
   const std::string *property(const std::string& name) const;
 #endif
 
+  void setAppRoot(const std::string& path);
   std::string appRoot() const;
   bool behindReverseProxy() const;
   std::string redirectMessage() const;
@@ -167,9 +168,6 @@ public:
   bool useSlashExceptionForInternalPaths() const;
   bool needReadBodyBeforeResponse() const;
   bool webglDetect() const;
-#ifndef WT_TARGET_JAVA
-  bool singleSession() const; // Only applicable for wthttp connector
-#endif // WT_TARGET_JAVA
 
   bool agentIsBot(const std::string& agent) const;
   bool agentSupportsAjax(const std::string& agent) const;
@@ -182,9 +180,6 @@ public:
   void setUseSlashExceptionForInternalPaths(bool enabled);
   void setNeedReadBodyBeforeResponse(bool needed);
   void setBehindReverseProxy(bool enabled);
-#ifndef  WT_TARGET_JAVA
-  void setSingleSession(bool singleSession);
-#endif
 
   std::string generateSessionId();
   bool registerSessionId(const std::string& oldId, const std::string& newId);
@@ -245,9 +240,6 @@ private:
   bool            sessionIdCookie_;
   bool            cookieChecks_;
   bool            webglDetection_;
-#ifndef WT_TARGET_JAVA
-  bool            singleSession_;
-#endif // WT_TARGET_JAVA
 
   std::vector<BootstrapEntry> bootstrapConfig_;
   std::vector<MetaHeader> metaHeaders_;
