@@ -86,6 +86,8 @@ public:
 
   void setJSSynced(bool invisibleToo);
 
+  void setStatelessSlotNotStateless() { currentStatelessSlotIsActuallyStateless_ = false; }
+
 private:
   struct CookieValue {
     std::string value;
@@ -102,9 +104,12 @@ private:
   WebSession& session_;
 
   bool visibleOnly_, rendered_, initialStyleRendered_;
-  int twoPhaseThreshold_, pageId_, expectedAckId_, scriptId_;
+  int twoPhaseThreshold_, pageId_, expectedAckId_, scriptId_, ackErrs_;
+  int linkedCssCount_;
   std::string solution_;
 
+  bool currentStatelessSlotIsActuallyStateless_;
+
   std::map<std::string, CookieValue> cookiesToSet_;
 
   FormObjectsMap currentFormObjects_;
