@@ -274,15 +274,14 @@ this.initAjaxComm = function(url, handler) {
 
 	  clearTimeout(timer);
 
+	  if (!sessionUrl)
+	    return;
+
 	  if (good) {
 	    handled = true;
 	    handler(0, request.responseText, userData);
-		if(monitor)
-		  monitor.onStatusChange('connectionStatus', 1);
 	  } else {
 	    handler(1, null, userData); 
-		if(monitor)
-		  monitor.onStatusChange('connectionStatus', 0);
 	  }
 
 	  if (request) {
@@ -312,6 +311,9 @@ this.initAjaxComm = function(url, handler) {
 	}
 
 	function handleTimeout() {
+	  if (!sessionUrl)
+	    return;
+
 	  request.onreadystatechange = new Function;
 	  request = null;
 	  handled = true;
@@ -319,7 +321,7 @@ this.initAjaxComm = function(url, handler) {
 	}
 
 	this.abort = function() {
-	  if(request != null){
+	  if (request != null) {
 	    request.onreadystatechange = new Function;
 	    handled = true;
 	    request.abort();
@@ -352,14 +354,14 @@ this.initAjaxComm = function(url, handler) {
       this.responseReceived = function(updateId) { };
 
       this.sendUpdate = function(data, userData, id, timeout) {
+	if (!sessionUrl)
+	  return null;
 	return new Request(data, userData, id, timeout);
       };
 
-	  var monitor = null;
-
-	  this.setConnectionMonitor = function(aMonitor) {
-		monitor = aMonitor;
-	  }
+      this.cancel = function() {
+	sessionUrl = null;
+      };
 
       this.setUrl = function(url) {
 	sessionUrl = url;
@@ -404,10 +406,16 @@ this.initAjaxComm = function(url, handler) {
       };
 
       this.sendUpdate = function(data, userData, id, timeout) {
+	if (!sessionUrl)
+	  return null;
         request = new Request(data, userData, id, timeout);
         return request;
       };
 
+      this.cancel = function() {
+	sessionUrl = null;
+      };
+
       this.setUrl = function(url) {
 	sessionUrl = url;
       };
@@ -497,10 +505,26 @@ this.insertAt = function(p, c, pos) {
 this.remove = function(id)
 {
   var e = WT.getElement(id);
-  if (e)
+  if (e) {
+    WT.saveReparented(e);
     e.parentNode.removeChild(e);
+  }
 };
 
+this.replaceWith = function(w1Id, $w2)
+{
+  var $w1 = $("#" + w1Id);
+  $w1.replaceWith($w2);
+
+  /* Reapply client-side validation, bootstrap applys validation classes
+     also outside the element into its ancestors */
+  if ($w2.get(0).wtValidate && WT.validate) {
+    setTimeout(function() { 
+      WT.validate($w2.get(0));
+    }, 0);
+  }
+}
+
 this.contains = function(w1, w2) {
   var p = w2.parentNode;
 
@@ -2425,10 +2449,11 @@ function encodeTouches(s, touches, widgetCoords) {
     if (i != 0)
       result += ';';
     result += [ t.identifier,
-		t.clientX, t.clientY,
-		t.pageX, t.pageY,
-		t.screenX, t.screenY,
-		t.pageX - widgetCoords.x, t.pageY - widgetCoords.y ].join(';');
+		Math.round(t.clientX), Math.round(t.clientY),
+		Math.round(t.pageX), Math.round(t.pageY),
+		Math.round(t.screenX), Math.round(t.screenY),
+		Math.round(t.pageX - widgetCoords.x),
+		Math.round(t.pageY - widgetCoords.y) ].join(';');
   }
 
   return result;
@@ -2588,7 +2613,6 @@ function encodeEvent(event, i) {
     result += se + 'charCode=' + charCode;
   }
 
-    
   if (typeof e.altKey !== UNDEFINED && 
       typeof e.altKey !== UNKNOWN &&
       e.altKey)
@@ -2642,8 +2666,8 @@ function encodePendingEvents() {
 }
 
 var sessionUrl,
-  quitted = false,
-  quittedStr = _$_QUITTED_STR_$_,
+  hasQuit = false,
+  quitStr = _$_QUITTED_STR_$_,
   loaded = false,
   responsePending = null,
   pollTimer = null,
@@ -2652,13 +2676,18 @@ var sessionUrl,
   serverPush = false,
   updateTimeout = null;
 
-function quit(quittedMessage) {
-  quitted = true;
-  quittedStr = quittedMessage;
+function quit(hasQuitMessage) {
+  hasQuit = true;
+  quitStr = hasQuitMessage;
   if (keepAliveTimer) {
     clearInterval(keepAliveTimer);
     keepAliveTimer = null;
   }
+  if (pollTimer) {
+    clearInterval(pollTimer);
+    pollTimer = null;
+  }
+  comm.cancel();
   var tr = $('#Wt-timers');
   if (tr.size() > 0)
     WT.setHtml(tr.get(0), '', false);
@@ -2715,7 +2744,7 @@ function load(fullapp) {
   if (fullapp)
     window._$_APP_CLASS_$_LoadWidgetTree();
 
-  if (!quitted) {
+  if (!hasQuit) {
     if (!keepAliveTimer) {
       keepAliveTimer = setInterval(doKeepAlive, _$_KEEP_ALIVE_$_000);
     }
@@ -2785,7 +2814,10 @@ function webSocketAckConnect() {
 }
 
 function handleResponse(status, msg, timer) {
-  if (quitted)
+  if (connectionMonitor)
+    connectionMonitor.onStatusChange('connectionStatus', status == 0 ? 1 : 0);
+
+  if (hasQuit)
     return;
 
   if (waitingForJavaScript) {
@@ -2834,7 +2866,7 @@ _$_$endif_$_();
   else
     commErrors = 0;
 
-  if (quitted)
+  if (hasQuit)
     return;
 
   if (websocket.state == WebSocketAckConnect)
@@ -2868,26 +2900,25 @@ function doPollTimeout() {
   responsePending = null;
   pollTimer = null;
 
-  if (!quitted)
+  if (!hasQuit)
     sendUpdate();
 }
 
-var updating = false;
- function setConnectionMonitor(aMonitor)
- {
-   comm.setConnectionMonitor(aMonitor);
-   connectionMonitor = aMonitor;
-   connectionMonitor.status = {};
-   connectionMonitor.status.connectionStatus = 0;
-   connectionMonitor.status.websocket = false;
-   connectionMonitor.onStatusChange = function(type, newS) {
-	var old = monitor.status[type];
-	if(old == newS) return;
-	monitor.status[type] = newS;
-	monitor.onChange(type, old, newS);
-   }
- }
+function setConnectionMonitor(aMonitor) {
+  connectionMonitor = aMonitor;
+  connectionMonitor.status = {};
+  connectionMonitor.status.connectionStatus = 0;
+  connectionMonitor.status.websocket = false;
+  connectionMonitor.onStatusChange = function(type, newS) {
+    var old = connectionMonitor.status[type];
+    if (old == newS)
+	return;
+    connectionMonitor.status[type] = newS;
+    connectionMonitor.onChange(type, old, newS);
+  };
+}
 
+var updating = false;
 
 function update(el, signalName, e, feedback) {
   /*
@@ -2943,15 +2974,15 @@ function schedulePing() {
 }
 
 function scheduleUpdate() {
-  if (quitted) {
-    if (!quittedStr)
+  if (hasQuit) {
+    if (!quitStr)
       return;
-    if (confirm(quittedStr)) {
+    if (confirm(quitStr)) {
       document.location = document.location;
-      quittedStr = null;
+      quitStr = null;
       return;
     } else {
-      quittedStr = null;
+      quitStr = null;
       return;
     }
   }
@@ -2969,7 +3000,7 @@ _$_$if_WEB_SOCKETS_$_();
 	  websocket.state = WebSocketUnavailable;
 	else {
 	  function reconnect() {
-	    if (!quitted) {
+	    if (!hasQuit) {
 	      ++websocket.reconnectTries;
 	      var ms = Math.min(120000, Math.exp(websocket.reconnectTries)
 				* 500);
@@ -3016,13 +3047,14 @@ _$_$if_WEB_SOCKETS_$_();
 		  webSocketAckConnect();
 	      } else {
 		console.log("WebSocket: was expecting a connect?");
+		console.log(event.data);
 		return;
 	      }
 	    } else {
 	      if (connectionMonitor) {
 		connectionMonitor.onStatusChange('websocket', true);
-	    connectionMonitor.onStatusChange('connectionStatus', 1);
-		  }
+		connectionMonitor.onStatusChange('connectionStatus', 1);
+	      }
               websocket.state = WebSocketWorking;
 	      js = event.data;
 	    }
@@ -3037,7 +3069,7 @@ _$_$if_WEB_SOCKETS_$_();
 	     * Sometimes, we can connect but cannot send data
 	     */
 	    if (connectionMonitor)
-		connectionMonitor.onStatusChange('websocket', false);
+	      connectionMonitor.onStatusChange('websocket', false);
 	    if (websocket.reconnectTries == 3 &&
 		websocket.state == WebSocketUnknown)
 	      websocket.state = WebSocketUnavailable;
@@ -3048,8 +3080,8 @@ _$_$if_WEB_SOCKETS_$_();
 	    /*
 	     * Sometimes, we can connect but cannot send data
 	     */
-	    if(connectionMonitor)
-			 connectionMonitor.onStatusChange('websocket', false);
+	    if (connectionMonitor)
+	      connectionMonitor.onStatusChange('websocket', false);
 	    if (websocket.reconnectTries == 3 &&
 		websocket.state == WebSocketUnknown)
 	      websocket.state = WebSocketUnavailable;
@@ -3068,8 +3100,8 @@ _$_$if_WEB_SOCKETS_$_();
 	     * So, we ping pong ourselves.
 	     */
 	    if (connectionMonitor) {
-		connectionMonitor.onStatusChange('websocket', true);
-		connectionMonitor.onStatusChange('connectionStatus', 1);
+	      connectionMonitor.onStatusChange('websocket', true);
+	      connectionMonitor.onStatusChange('connectionStatus', 1);
 	    }
 
 	    /*
@@ -3147,7 +3179,7 @@ function sendUpdate() {
 
   if (WT.isIEMobile) feedback = false;
 
-  if (quitted)
+  if (hasQuit)
     return;
 
   var data, tm, poll;
@@ -3184,7 +3216,7 @@ function sendUpdate() {
 
   var params = "_$_PARAMS_$_";
   if (params.length > 0)
-    data.result += '&' + params;
+    data.result += '&Wt-params=' + encodeURIComponent(params);
 
   if ((websocket.socket != null) &&
       (websocket.socket.readyState == 1) &&
@@ -3256,7 +3288,7 @@ function emit(object, config) {
       r = 0;
     else if (a === true)
       r = 1;
-    else if (a.toDateString)
+    else if (a && a.toDateString)
       r = a.toDateString();
     else
       r = a;
@@ -3490,7 +3522,7 @@ function ieAlternative(d)
 
 window.onunload = function()
 {
-  if (!quitted) {
+  if (!hasQuit) {
     self.emit(self, "Wt-unload");
     scheduleUpdate();
     sendUpdate();
@@ -3518,6 +3550,76 @@ function setCloseMessage(m)
     window.onbeforeunload = null;
 };
 
+var firstCall = true;
+var globalEventsFunctions = null;
+var keyEvents = [ 'keydown', 'keyup', 'keypress' ];
+
+function updateGlobal(id) {
+  firstCall = false;
+  var domId;
+  if (id == null) {
+    domId = $('.Wt-domRoot').get(0).id
+  } else {
+    domId = id;
+  }
+
+  for (var i = 0; i < keyEvents.length ; ++i) {
+    var elemEvents = globalEventsFunctions ? globalEventsFunctions[domId] : null;
+    var eventFunc = null;
+
+    if (elemEvents) 
+      eventFunc = elemEvents[keyEvents[i]];
+
+    var bindEvent = function(evtfunc) {
+      return function(event) {
+	var g=event||window.event;
+	var t=g.target||g.srcElement;
+	if ((!t| WT.hasTag(t,'DIV')
+	  || WT.hasTag(t,'BODY')
+	    || WT.hasTag(t,'HTML'))) {
+	      var func = evtfunc;
+	      if(func)
+		func(event);
+	    }
+      };
+    };
+
+    if (eventFunc)
+      document['on' + keyEvents[i] ] = bindEvent(eventFunc);
+    else 
+      document['on' + keyEvents[i] ] = null;
+
+  }
+
+  // cleanup functions of widgets that do no longer exist
+  if (globalEventsFunctions) {
+    for (var i in globalEventsFunctions) {
+      if (!document.getElementById(i)) {
+	delete globalEventsFunctions[i];
+      }
+    }
+  }
+}
+
+function bindGlobal(event, id, f) {
+  var init = false;
+  if (!globalEventsFunctions) {
+    globalEventsFunctions = {};
+    init = true;
+  }
+
+  // Saves the event functions
+  if (!globalEventsFunctions[id])
+    globalEventsFunctions[id] = {};
+
+  globalEventsFunctions[id][event]=f;
+  if(init)
+    setTimeout(function() {
+      if(firstCall)
+	updateGlobal(null);
+    }, 0);
+}
+
 this._p_ = {
   ieAlternative : ieAlternative,
   loadScript : loadScript,
@@ -3551,6 +3653,8 @@ this._p_ = {
   setPage : setPage,
   setCloseMessage : setCloseMessage,
   setConnectionMonitor : setConnectionMonitor,
+  updateGlobal: updateGlobal,
+  bindGlobal: bindGlobal,
 
   propagateSize : propagateSize
 };
